@@ -1,8 +1,14 @@
 "Livestreamer main class"
 
+from __future__ import print_function
+
 import os
 import sys
-from urllib.parse import urlsplit
+# Python 2/3 compatibility
+try:
+    from urllib.parse import urlsplit
+except ImportError:
+    from urlparse import urlsplit
 
 from livestreamer import Livestreamer, StreamError, PluginError, NoPluginError
 
